@@ -3,7 +3,7 @@ use {
 };
 
 /// settings of a drawer, saved in the drawer
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Default)]
 pub struct DrawerSettings {
     /// whether to hide unselected entry values
     pub hide_values: bool,
@@ -11,12 +11,3 @@ pub struct DrawerSettings {
     #[serde(default)]
     pub open_all_values: bool,
 }
-
-impl Default for DrawerSettings {
-    fn default() -> Self {
-        Self {
-            hide_values: false,
-            open_all_values: false,
-        }
-    }
-}
