@@ -138,6 +138,9 @@ impl AppState {
                 time!(self.open_closet.push_back(ds.drawer)?);
                 time!(self.open_closet.close_and_save())?;
             }
+        } else {
+            // saving only the closet
+            time!(self.open_closet.close_and_save())?;
         }
         Ok(())
     }
@@ -189,7 +192,7 @@ impl AppState {
                     self.set_info("string copied to the clipboard, be cautious");
                 }
             } else {
-                self.set_error("you can only copy from an edited input");
+                self.set_error("you can't copy from here");
             }
         }
     }
@@ -250,6 +253,28 @@ impl AppState {
         double_click: bool,
     )-> Result<(), SafeClosetError> {
 
+        match &mut self.dialog {
+            Dialog::Menu(menu) => {
+                if let Some(action) = menu.state.on_mouse_event(mouse_event, double_click) {
+                    self.on_action(action)?;
+                }
+                return Ok(());
+            }
+            Dialog::Help(help) => {
+                help.on_mouse_event(mouse_event, double_click);
+                return Ok(());
+            }
+            Dialog::Password(password_dialog) => {
+                password_dialog.on_mouse_event(mouse_event, double_click);
+                return Ok(());
+            }
+            Dialog::CommentsEditor(comments_editor) => {
+                comments_editor.on_mouse_event(mouse_event, double_click);
+                return Ok(());
+            }
+            Dialog::None => {}
+        }
+
         if let Some(input) = self.drawer_input() {
             if input.apply_mouse_event(mouse_event, double_click) {
                 return Ok(());
@@ -267,32 +292,35 @@ impl AppState {
             match kind {
                 MouseEventKind::Up(MouseButton::Left) => {
                     if modifiers == KeyModifiers::NONE {
-                        if let Some(clicked_line) = ds.clicked_line(row as usize) {
-                            use DrawerFocus::*;
-                            // if we're here we know the clicked input isn't focused
-                            let in_name = ds.layout().is_in_name_column(column);
-                            if in_name {
+                        // The case of an input being focused is handled before
+                        // so we know it's not the case
+                        match ds.clicked(column, row as usize) {
+                            Clicked::Search => {
+                                self.on_action(Action::Search)?;
+                            }
+                            Clicked::Name(clicked_line) => {
                                 if ds.focus.is_name_selected(clicked_line) {
                                     ds.edit_entry_name_by_line(clicked_line, EditionPos::Start);
                                 } else {
-                                    ds.focus = NameSelected { line: clicked_line };
+                                    ds.focus = DrawerFocus::NameSelected { line: clicked_line };
                                 }
-                            } else {
+                            }
+                            Clicked::Value(clicked_line) => {
                                 if ds.focus.is_value_selected(clicked_line) {
                                     ds.edit_entry_value_by_line(clicked_line, EditionPos::Start);
                                 } else {
-                                    ds.focus = ValueSelected { line: clicked_line };
+                                    ds.focus = DrawerFocus::ValueSelected { line: clicked_line };
                                 }
-
                             }
+                            Clicked::Nothing => {}
                         }
                     }
                 }
                 MouseEventKind::ScrollUp => {
-                    ds.move_line(Direction::Up);
+                    ds.apply_scroll_command(ScrollCommand::Lines(-1));
                 }
                 MouseEventKind::ScrollDown => {
-                    ds.move_line(Direction::Down);
+                    ds.apply_scroll_command(ScrollCommand::Lines(1));
                 }
                 _ => {}
             }
@@ -320,7 +348,7 @@ impl AppState {
                 let mut menu = Menu::default();
                 menu.add_item(Action::ConfirmEntryRemoval);
                 menu.add_item(Action::Back);
-                menu.select(1);
+                menu.state.select(1);
                 self.dialog = Dialog::Menu(menu);
             }
         }
@@ -454,6 +482,11 @@ impl AppState {
                     )
                 );
             }
+            Action::EditClosetComments => {
+                self.dialog = Dialog::CommentsEditor(
+                    CommentsEditor::new(&self.open_closet.root_closet().comments)
+                );
+            }
             Action::SaveDrawer => {
                 if self.drawer_state.is_some() {
                     self.dialog = Dialog::None;
@@ -623,6 +656,8 @@ impl AppState {
                 menu.add_item(Action::OpenAllValues);
             }
             menu.add_item(Action::OpenPasswordChangeDialog);
+        } else {
+            menu.add_item(Action::EditClosetComments);
         }
         menu.add_item(Action::Help);
         menu.add_item(Action::Quit);
@@ -659,6 +694,11 @@ impl AppState {
                     return Ok(CmdResult::Stay);
                 }
             }
+            Dialog::CommentsEditor(comments_editor) => {
+                if comments_editor.apply_key_event(key) {
+                    return Ok(CmdResult::Stay);
+                }
+            }
             Dialog::None => {}
         }
 
@@ -667,21 +707,31 @@ impl AppState {
         }
 
         if key == ENTER {
-            if let Dialog::Password(password_dialog) = &self.dialog {
-                let password = password_dialog.get_password();
-                match password_dialog.purpose() {
-                    PasswordDialogPurpose::NewDrawer { .. } => {
-                        self.queue_task(Task::CreateDrawer(password));
-                    }
-                    PasswordDialogPurpose::OpenDrawer { .. } => {
-                        self.queue_task(Task::OpenDrawer(password));
-                    }
-                    PasswordDialogPurpose::ChangeDrawerPassword => {
-                        self.queue_task(Task::ChangePassword(password));
+            match &mut self.dialog {
+                Dialog::Password(password_dialog) => {
+                    let password = password_dialog.get_password();
+                    match password_dialog.purpose() {
+                        PasswordDialogPurpose::NewDrawer { .. } => {
+                            self.queue_task(Task::CreateDrawer(password));
+                        }
+                        PasswordDialogPurpose::OpenDrawer { .. } => {
+                            self.queue_task(Task::OpenDrawer(password));
+                        }
+                        PasswordDialogPurpose::ChangeDrawerPassword => {
+                            self.queue_task(Task::ChangePassword(password));
+                        }
                     }
                 }
-            } else {
-                self.close_drawer_input(false); // if there's an entry input
+                Dialog::Help(_) => {}
+                Dialog::Menu(_) => {} // managed in the menu
+                Dialog::CommentsEditor(ce) => {
+                    self.open_closet.root_closet().comments = ce.get_comments();
+                    self.dialog = Dialog::None;
+                    self.queue_task(Task::Save);
+                }
+                Dialog::None => {
+                    self.close_drawer_input(false); // if there's an entry input
+                }
             }
             return Ok(CmdResult::Stay);
         }
