@@ -16,7 +16,4 @@ impl Dialog {
     pub fn is_some(&self) -> bool {
         !self.is_none()
     }
-    pub fn is_help(&self) -> bool {
-        matches!(self, Self::Help(_))
-    }
 }
