@@ -71,6 +71,10 @@ pub(crate) use {
 
 pub const MAX_INACTIVITY: Duration = Duration::from_secs(60);
 
+pub trait ScreenWriter {
+    fn go_to(&mut self, x: u16, y: u16) -> Result<(), SafeClosetError>;
+}
+
 /// the type used by all TUI writing functions
 pub type W = std::io::BufWriter<std::io::Stdout>;
 
@@ -79,6 +83,13 @@ fn writer() -> W {
     std::io::BufWriter::new(std::io::stdout())
 }
 
+impl ScreenWriter for W {
+    fn go_to(&mut self, x: u16, y: u16) -> Result<(), SafeClosetError> {
+        self.queue(cursor::MoveTo(x, y))?;
+        Ok(())
+    }
+}
+
 pub fn run(
     open_closet: OpenCloset,
     args: &Args,
